@@ -136,12 +136,11 @@ struct BatchProgressDialog::Private {
 /////////////////////////////////// CONSTRUCTOR ////////////////////////////////////////////
 
 BatchProgressDialog::BatchProgressDialog( QWidget *parent, const QString &caption )
-                   : KDialogBase( KDialogBase::Plain, caption, Help|Cancel,
-                                  Cancel, parent, "KIPIBatchProgressDialog", true )
+                   : KDialogBase( parent, "KIPIBatchProgressDialog", true /* modal */,
+                                  caption, Cancel)
 {
     d = new Private;
-    QWidget* box = plainPage();
-    QVBoxLayout *dvlay = new QVBoxLayout( box, 6 );
+    QWidget* box = makeVBoxMainWidget();
 
     //---------------------------------------------
 
@@ -156,7 +155,6 @@ BatchProgressDialog::BatchProgressDialog( QWidget *parent, const QString &captio
     QLabel *labelTitle = new QLabel( caption, headerFrame, "labelTitle" );
     layout->addWidget( labelTitle );
     layout->setStretchFactor( labelTitle, 1 );
-    dvlay->addWidget( headerFrame );
 
     QString dir;
     KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
@@ -168,29 +166,8 @@ BatchProgressDialog::BatchProgressDialog( QWidget *parent, const QString &captio
 
     //---------------------------------------------
 
-    // About data and help button.
 
-    KAboutData* about = new KAboutData("kipiplugins",
-                                       I18N_NOOP("Batch process dialog"),
-                                       kipi_version,
-                                       I18N_NOOP("A Kipi dialog for batch process operations"),
-                                       KAboutData::License_GPL,
-                                       "(c) 2004,2005, Kipi development team",
-                                       0,
-                                       "http://extragear.kde.org/apps/kipi");
-
-    QPushButton *helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
-    helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Kipi Plugins Handbooks"), this, SLOT(slotHelp()), 0, -1, 0);
-    helpButton->setPopup( helpMenu->menu() );
-
-    //---------------------------------------------
-
-
-    QGroupBox* groupBox1 = new QGroupBox( 2, Qt::Horizontal, box );
-
-    m_actionsList = new KListView( groupBox1 );
+    m_actionsList = new KListView( box );
     m_actionsList->addColumn(i18n( "Status" ));
     m_actionsList->addColumn(i18n( "Current Actions" ));
     m_actionsList->setSorting(-1);
@@ -198,7 +175,6 @@ BatchProgressDialog::BatchProgressDialog( QWidget *parent, const QString &captio
     m_actionsList->header()->hide();
     m_actionsList->setResizeMode(QListView::LastColumn);
     QWhatsThis::add( m_actionsList, i18n("<p>This is the current tasks list released.") );
-    dvlay->addWidget( groupBox1 );
 
     //---------------------------------------------
 
@@ -206,7 +182,6 @@ BatchProgressDialog::BatchProgressDialog( QWidget *parent, const QString &captio
     m_progress->setTotalSteps(100);
     m_progress->setValue(0);
     QWhatsThis::add( m_progress, i18n("<p>This is the list current percent task released.") );
-    dvlay->addWidget( m_progress );
     resize( 600, 400 );
 }
 
@@ -244,15 +219,6 @@ void BatchProgressDialog::setProgress(int current, int total)
     m_progress->setValue(current);
 }
 
-/////////////////////////////////////// SLOTS ///////////////////////////////////////////////
-
-
-void BatchProgressDialog::slotHelp( void )
-{
-    KApplication::kApplication()->invokeHelp("",
-                                             "kipi-plugins");
-}
-
 }  // NameSpace KIPI
 
 #include "batchprogressdialog.moc"
